aboutsummaryrefslogtreecommitdiff
path: root/ref/store/transactional_store.go
diff options
context:
space:
mode:
Diffstat (limited to 'ref/store/transactional_store.go')
-rw-r--r--ref/store/transactional_store.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/ref/store/transactional_store.go b/ref/store/transactional_store.go
index 8a061f54..10f4543a 100644
--- a/ref/store/transactional_store.go
+++ b/ref/store/transactional_store.go
@@ -1,11 +1,11 @@
package refstore
// TransactionalStore begins atomic reference transactions.
//
// Not every readable reference store is writable. Implementations should only
// satisfy TransactionalStore when they can stage and commit reference updates
// atomically within that backend.
-type TransactionalStore interface {
+type Transactioner interface {
// BeginTransaction creates one new mutable transaction.
//
// Labels: Life-Parent.
@@ -1,11 +1,11 @@
package refstore
-// TransactionalStore begins atomic reference transactions.
+// Transactioner begins atomic reference transactions.
//
// Not every readable reference store is writable. Implementations should only
@@ -1,11 +1,11 @@
//
// Not every readable reference store is writable. Implementations should only
-// satisfy TransactionalStore when they can stage and commit reference updates
+// satisfy Transactioner when they can stage and commit reference updates
// atomically within that backend.